## Description of the problem

_Provide a concise description of the bug_

## Steps to reproduce it

_List the steps to reproduce the problem:_

1. Visit '...'
2. Click on '...'
3. Scroll to '...'
4. ...

### Expected behavior

_A clear and concise description of what you expect to happen._

### Behavior detected

_A clear and concise description of what happens instead._

## Screenshots

_If relevant, copy and paste screenshots or photos of the problem here._

/label ~bug
